require "language/node"

class BitwardenCli < Formula
  desc "Secure and free password manager for all of your devices"
  homepage "https://bitwarden.com/"
  url "https://github.com/bitwarden/clients/archive/refs/tags/cli-v2024.6.1.tar.gz"
  sha256 "1dff0f6af422864aa9a4e8c226282cb3f4346a4c8e661effe2571e1553603e56"
  license "GPL-3.0-only"

  depends_on "node"

  def install
    Language::Node.setup_npm_environment
    system "npm", "ci", "--ignore-scripts"
    cli_root = buildpath/"apps/cli" # Bitwarden's source code is a monorepo
    cd cli_root do
      # The `oss` build of Bitwarden is a GPL backed build
      system "npm", "run", "build:oss:prod", "--ignore-scripts"
      cd cli_root/"build" do
        system "npm", "install", *Language::Node.std_npm_install_args(libexec)
        bin.install_symlink Dir[libexec/"bin/*"]
      end
    end

    generate_completions_from_executable(
      bin/"bw", "completion",
      base_name: "bw", shell_parameter_format: :arg, shells: [:zsh]
    )
  end

  test do
    assert_equal 10, shell_output("#{bin}/bw generate --length 10").chomp.length

    output = pipe_output("#{bin}/bw encode", "Testing", 0)
    assert_equal "VGVzdGluZw==", output.chomp
  end
end
